# -*- coding: utf-8 -*-

from imio.smartweb.policy.utils import add_navigation_links
from imio.smartweb.policy.utils import clear_manager_portlets
from imio.smartweb.policy.utils import remove_unused_contents
from plone import api
from Products.CMFPlone.interfaces import INonInstallable
from Products.CMFQuickInstallerTool import interfaces as quiskinstallinterfaces
from zope.interface import implementer


@implementer(INonInstallable)
class HiddenProfiles(object):
    def getNonInstallableProfiles(self):
        """Hide uninstall profile from site-creation and quickinstaller."""
        return [
            "imio.smartweb.core:default",
            "imio.smartweb.policy:uninstall",
        ]


@implementer(quiskinstallinterfaces.INonInstallable)
class HiddenProducts(object):
    def getNonInstallableProducts(self):
        """Hides profiles from QuickInstaller"""
        return [
            "imio.smartweb.core",
        ]


def post_install(context):
    """Post install script"""
    portal = api.portal.get()
    remove_unused_contents(portal)
    clear_manager_portlets(portal, "plone.leftcolumn")
    clear_manager_portlets(portal, "plone.rightcolumn")
    clear_manager_portlets(portal, "plone.footerportlets")
    add_navigation_links(portal)


def uninstall(context):
    """Uninstall script"""
    # Do something at the end of the uninstallation of this package.



# -*- coding: utf-8 -*-

from imio.smartweb.common.utils import get_vocabulary
from imio.smartweb.locales import SmartwebMessageFactory as _
from plone import api
from plone.portlets.interfaces import IPortletAssignmentMapping
from plone.portlets.interfaces import IPortletManager
from zope.component import getMultiAdapter
from zope.component import getUtility
from zope.globalrequest import getRequest
from zope.i18n import translate


def remove_unused_contents(portal):
    api.content.delete(portal.news)
    api.content.delete(portal.events)
    api.content.delete(portal.Members)


def clear_manager_portlets(folder, manager_name):
    manager = getUtility(IPortletManager, name=manager_name, context=folder)
    assignments = getMultiAdapter((folder, manager), IPortletAssignmentMapping)
    for portlet in assignments:
        del assignments[portlet]


def add_iam_folder(context, current_lang):
    i_am_folder = api.content.create(
        container=context,
        type="imio.smartweb.Folder",
        title=translate(_("I am"), target_language=current_lang),
    )
    api.content.transition(i_am_folder, "publish")

    i_am_vocabulary = get_vocabulary("imio.smartweb.vocabulary.IAm")
    for term in i_am_vocabulary:
        link = api.content.create(
            container=i_am_folder,
            type="Link",
            title=translate(_(term.title), target_language=current_lang),
        )
        link.remoteUrl = "{0}/@@search?iam={1}".format("${portal_url}", term.token)
        api.content.transition(link, "publish")


def add_ifind_folder(context, current_lang):
    i_find_folder = api.content.create(
        container=context,
        type="imio.smartweb.Folder",
        title=translate(_("I find"), target_language=current_lang),
    )
    api.content.transition(i_find_folder, "publish")
    collection = api.content.create(
        container=i_find_folder,
        type="Collection",
        title=translate(
            _("Procedures and practical informations"), target_language=current_lang
        ),
    )
    collection.query = [
        {
            "i": "portal_type",
            "o": "plone.app.querystring.operation.selection.any",
            "v": ["imio.smartweb.Procedure"],
        }
    ]
    api.content.transition(collection, "publish")
    request = getRequest()
    request.form = {
        "cid": "page-category",
        "faceted.page-category.index": "taxonomy_procedure_category",
        "faceted.page-category.vocabulary": "collective.taxonomy.procedure_category",
    }
    handler = getMultiAdapter((collection, request), name="faceted_update_criterion")
    handler.edit(**request.form)


def add_navigation_links(context):
    current_lang = api.portal.get_current_language()[:2]
    add_iam_folder(context, current_lang)
    add_ifind_folder(context, current_lang)



# -*- coding: utf-8 -*-

from plone.app.caching.operations.default import ModerateCaching
from plone.app.caching.operations.default import StrongCaching
from plone.app.caching.operations.default import TerseCaching
from plone.app.caching.operations.default import WeakCaching
from plone.caching.interfaces import ICachingOperationType
from plone.caching.utils import lookupOptions
from zope.interface import provider


class PatchedCachingMixin:
    def interceptResponse(self, rulename, response, class_=None):
        result = super(PatchedCachingMixin, self).interceptResponse(
            rulename, response, class_
        )
        if result != "":
            # "" is the result of a 304 NOT MODIFIED
            return result

        options = lookupOptions(class_ or self.__class__, rulename)
        maxage = options.get("maxage", self.maxage)
        smaxage = options.get("smaxage", self.smaxage)

        if maxage:
            if smaxage is not None:
                maxage = f"{maxage}, s-maxage={smaxage}"
            response.setHeader(
                "Cache-Control",
                f"max-age={maxage}, proxy-revalidate, public",
            )
        elif smaxage:
            response.setHeader(
                "Cache-Control",
                f"max-age=0, s-maxage={smaxage}, must-revalidate",
            )
        else:
            response.setHeader("Cache-Control", "max-age=0, must-revalidate, private")

        return ""


@provider(ICachingOperationType)
class PatchedModerateCaching(PatchedCachingMixin, ModerateCaching):
    """Moderate caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedStrongCaching(PatchedCachingMixin, StrongCaching):
    """Strong caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedTerseCaching(PatchedCachingMixin, TerseCaching):
    """Terse caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedWeakCaching(PatchedCachingMixin, WeakCaching):
    """Weak caching with Cache-Control heaader set, even for 304"""
